pub struct ModeTransition {
pub from: Mode,
pub to: Mode,
}Expand description
A one-shot transition request — emitted by the keymap, consumed by the editor loop.
Fields
from: Modeto: ModeTrait Implementations
Sourceimpl Clone for ModeTransition
impl Clone for ModeTransition
Sourcefn clone(&self) -> ModeTransition
fn clone(&self) -> ModeTransition
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for ModeTransition
Sourceimpl Debug for ModeTransition
impl Debug for ModeTransition
Sourceimpl<'de> Deserialize<'de> for ModeTransition
impl<'de> Deserialize<'de> for ModeTransition
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ModeTransition
Sourceimpl JsonSchema for ModeTransition
impl JsonSchema for ModeTransition
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ModeTransition
impl PartialEq for ModeTransition
Sourcefn eq(&self, other: &ModeTransition) -> bool
fn eq(&self, other: &ModeTransition) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ModeTransition
impl Serialize for ModeTransition
impl StructuralPartialEq for ModeTransition