Operator

Enum Operator 

pub enum Operator {
Show 14 variants Delete, Yank, Change, Indent, Dedent, Filter, Format, SlurpForward, SlurpBackward, BarfForward, BarfBackward, Splice, Wrap, Raise,
}
Operators — vim-style verbs. Combined with a motion they produce an edit.

Structural operators (paredit-grade) compose with structural motions:

  • (slurp-forward) — pull the next sibling into the current list
  • (barf-forward) — push the last child out of the current list
  • (splice) — unwrap the current list (remove parens, keep children)
  • (wrap) — wrap the target in a new list
  • (raise) — replace the enclosing list with the current sexp

Variants



Delete



Yank



Change



Indent



Dedent



Filter



Format



SlurpForward



SlurpBackward



BarfForward



BarfBackward



Splice



Wrap



Raise

Implementations

Source

impl Operator

pub const fn leaves_register(self) -> bool

pub const fn is_structural(self) -> bool